@@ -109,8 +109,8 @@ static const int tool_icon_sizes[] = {
     GTK_ICON_SIZE_DIALOG };
 // also change max_icon_size in settings.c & lists in prefdlg.ui prefdlg2.ui
 // see create_size in vfs-thumbnail-loader.c:_vfs_thumbnail_load()
-static const int big_icon_sizes[] = { 512, 256, 192, 128, 96, 72, 64, 48, 36, 32, 24, 22 };
-static const int small_icon_sizes[] = { 512, 256, 192, 128, 96, 72, 64, 48, 36, 32, 24, 22, 16, 12 };
+static const int big_icon_sizes[] = { 512, 384, 256, 192, 128, 96, 72, 64, 48, 36, 32, 24, 22 };
+static const int small_icon_sizes[] = { 512, 384, 256, 192, 128, 96, 72, 64, 48, 36, 32, 24, 22, 16, 12 };
 static const char* date_formats[] =
 {
     "%Y-%m-%d %H:%M",
@@ -772,7 +772,19 @@ static void on_response( GtkDialog* dlg, int response, FMPrefDlg* user_data )
                                strstr( terminal, "urxvtc" ) ||
                                strstr( terminal, "konsole" ) ||
                                strstr( terminal, "gnome-terminal" ) ) )
-                xset_msg_dialog( GTK_WIDGET( dlg ), 0, _("Limited Terminal Emulator Selected"), NULL, 0, _("Due to limitations of gnome-terminal, konsole, lxterminal, and urxvtc, use of these terminals with SpaceFM may prevent the Run As Task and Run In Terminal options being used together to run commands.  For example, this may cause protocols mounted in a terminal to fail to automatically open after being mounted.  For full use of SpaceFM's features, selecting another terminal is recommended."), NULL, "#designmode-command-terminal" );
+                        /* when changing this list adjust also
+                         * vfs-file-task.c Line ~1655
+                         * ptk-location-view.c:ptk_location_view_mount_network()
+                         * and string below */
+            {
+                str = g_strdup_printf( _("Use of some terminals (%s) with SpaceFM may prevent the Run As Task and Run In Terminal options being used together to run commands, due to limitations in these terminals.  For example, this may cause protocols mounted in a terminal to fail to automatically open after being mounted.  For full use of SpaceFM's features, selecting another terminal is recommended."),
+                    "gnome-terminal, konsole, lxterminal, urxvtc" );
+                xset_msg_dialog( GTK_WIDGET( dlg ), 0,
+                                    _("Limited Terminal Emulator Selected"),
+                                    NULL, 0, str, NULL,
+                                    "#designmode-command-terminal" );
+                g_free( str );
+            }
         }
         // report missing terminal
         if ( str = strchr( terminal, ' ' ) )
